#[non_exhaustive]pub struct Comprehension {
pub return_expression: Expression,
pub qualifiers: Vec<ComprehensionQualifier>,
pub skip_operator: Option<ACOperatorKind>,
/* private fields */
}Expand description
A comprehension.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.return_expression: Expressionqualifiers: Vec<ComprehensionQualifier>skip_operator: Option<ACOperatorKind>When this comprehension appears inside an AC operator, records which operator so expansion can apply the correct skip semantics for symbolic guards.
Implementations
Sourceimpl Comprehension
impl Comprehension
pub fn domain_of(&self) -> Option<Moo<Domain>>
pub fn return_expression(self) -> Expression
pub fn replace_return_expression(&mut self, new_expr: Expression)
pub fn symbols(&self) -> RwLockReadGuard<'_, RawRwLock, SymbolTable>
pub fn quantified_vars(&self) -> Vec<Name>
pub fn generator_conditions(&self) -> Vec<Expression>
Sourcepub fn to_generator_model(&self) -> Model
pub fn to_generator_model(&self) -> Model
Builds a temporary model containing generator qualifiers and guards.
Sourcepub fn to_return_expression_model(&self) -> Model
pub fn to_return_expression_model(&self) -> Model
Builds a temporary model containing the return expression only.
Sourcepub fn add_quantified_guard(&mut self, guard: Expression) -> bool
pub fn add_quantified_guard(&mut self, guard: Expression) -> bool
Adds a guard to the comprehension.
Returns false if the guard references non-quantified decision variables.
Sourcepub fn is_quantified_guard(&self, expr: &Expression) -> bool
pub fn is_quantified_guard(&self, expr: &Expression) -> bool
True iff expr does not reference non-quantified decision variables.