pub struct ComprehensionBuilder { /* private fields */ }Expand description
A builder for a comprehension.
Implementations
Sourceimpl ComprehensionBuilder
impl ComprehensionBuilder
pub fn new(symbol_table_ptr: SymbolTablePtr) -> ComprehensionBuilder
Sourcepub fn generator_symboltable(&mut self) -> SymbolTablePtr
pub fn generator_symboltable(&mut self) -> SymbolTablePtr
Backwards-compatible parser API: same table for generators and return expression.
Sourcepub fn return_expr_symboltable(&mut self) -> SymbolTablePtr
pub fn return_expr_symboltable(&mut self) -> SymbolTablePtr
Backwards-compatible parser API: same table for generators and return expression.
pub fn guard(self, guard: Expression) -> ComprehensionBuilder
pub fn generator(self, declaration: DeclarationPtr) -> ComprehensionBuilder
Sourcepub fn with_return_value(
self,
expression: Expression,
comprehension_kind: Option<ACOperatorKind>,
) -> Comprehension
pub fn with_return_value( self, expression: Expression, comprehension_kind: Option<ACOperatorKind>, ) -> Comprehension
Creates a comprehension with the given return expression.
If this comprehension is inside an AC-operator, the kind of this operator should be passed
in the comprehension_kind field.
If a comprehension kind is not given, comprehension guards containing decision variables are invalid, and will cause a panic.