AbstractLiteral

Enum AbstractLiteral 

pub enum AbstractLiteral<T>
where T: AbstractLiteralValue,
{ Set(Vec<T>), MSet(Vec<T>), Matrix(Vec<T>, <T as AbstractLiteralValue>::Dom), Tuple(Vec<T>), Record(Vec<Field<T>>), Sequence(Vec<T>), Function(Vec<(T, T)>), Variant(Moo<Field<T>>), Partition(Vec<Vec<T>>), Relation(Vec<Vec<T>>), Permutation(Vec<Vec<T>>), }

Variants



Set(Vec<T>)



MSet(Vec<T>)



Matrix(Vec<T>, <T as AbstractLiteralValue>::Dom)

A 1 dimensional matrix slice with an index domain.



Tuple(Vec<T>)



Record(Vec<Field<T>>)



Sequence(Vec<T>)



Function(Vec<(T, T)>)



Variant(Moo<Field<T>>)



Partition(Vec<Vec<T>>)



Relation(Vec<Vec<T>>)



Permutation(Vec<Vec<T>>)

Cycle notation for a permutation: each inner vec is one cycle. Unlike Partition, this is sparse – any element of the permutation’s domain not mentioned in any cycle is an implicit fixed point (maps to itself), rather than every element needing to be covered.

Implementations

Source

impl AbstractLiteral<Expression>

pub fn domain_of(&self) -> Option<Moo<Domain>>

Source

impl<T> AbstractLiteral<T>
where T: AbstractLiteralValue,

pub fn matrix_implied_indices(elems: Vec<T>) -> AbstractLiteral<T>

Creates a matrix with elements elems, with domain int(1..).

This acts as a variable sized list.

pub fn unwrap_list(&self) -> Option<&Vec<T>>

If the AbstractLiteral is a list, returns its elements.

A list is any a matrix with the domain int(1..). This includes matrix literals without any explicitly specified domain.

pub fn into_list(self) -> Option<Vec<T>>

If this abstract literal is a list, consumes it and returns its elements.

Source

impl AbstractLiteral<Expression>

pub fn into_literals(self) -> Option<AbstractLiteral<Literal>>

If all the elements are literals, returns this as an AbstractLiteral. Otherwise, returns None.