pretty_variable_declaration

Function pretty_variable_declaration 

pub fn pretty_variable_declaration(
    symbol_table: &SymbolTable,
    var_name: &Name,
) -> Option<String>
Pretty prints, in essence syntax, the variable declaration for the given symbol.

E.g.

find a: int(1..5)

When a representation has been selected for an abstract domain, the domain is printed with that representation’s short name, e.g. find x: set (representation occurrence, maxSize 3) of int(1..4).

Returns None if the symbol is not in the symbol table, or if it is not a variable.