pub struct SymbolTablePtr{ /* private fields */ }Implementations
Sourceimpl SymbolTablePtr
impl SymbolTablePtr
Sourcepub fn new() -> SymbolTablePtr
pub fn new() -> SymbolTablePtr
Create an empty new SymbolTable and return a shared pointer to it
Sourcepub fn with_parent(symbols: SymbolTablePtr) -> SymbolTablePtr
pub fn with_parent(symbols: SymbolTablePtr) -> SymbolTablePtr
Create an empty new SymbolTable with the given parent and return a shared pointer to it
Sourcepub fn read(&self) -> RwLockReadGuard<'_, RawRwLock, SymbolTable>
pub fn read(&self) -> RwLockReadGuard<'_, RawRwLock, SymbolTable>
Read the underlying symbol table. This will block the current thread until a read lock can be acquired.
WARNING
- If the current thread already holds a lock over this table, this may deadlock.
Sourcepub fn write(&self) -> RwLockWriteGuard<'_, RawRwLock, SymbolTable>
pub fn write(&self) -> RwLockWriteGuard<'_, RawRwLock, SymbolTable>
Mutate the underlying symbol table. This will block the current thread until an exclusive write lock can be acquired.
WARNING
- If the current thread already holds a lock over this table, this may deadlock.
- Trying to acquire any other lock until the write lock is released will cause a deadlock.
- This will mutate the underlying data, which may be shared between other
SymbolTablePtrs. Make sure that this is what you want.
To create a separate copy of the table, see SymbolTablePtr::detach.
Sourcepub fn detach(&self) -> SymbolTablePtr
pub fn detach(&self) -> SymbolTablePtr
Create a new symbol table with the same contents as this one, but a new ID, and return a pointer to it.