pub fn instantiate_model(
problem_model: Model,
param_model: Model,
) -> Result<Model, Error>Expand description
Instantiate a problem model with values from a parameter model.
For each given declaration in problem_model, this looks for a corresponding value letting
in param_model, checks it is a constant and within the given domain, and replaces the given
with a value-letting in the returned model.