pub enum ParseErrorCollection {
Fatal(FatalParseError),
Multiple {
errors: Vec<RecoverableParseError>,
},
}Expand description
Collection of parse errors
Variants
Fatal(FatalParseError)
A single fatal error that stops parsing entirely
Multiple
Multiple recoverable errors accumulated during parsing
Fields

errors: Vec<RecoverableParseError>Implementations
Sourceimpl ParseErrorCollection
impl ParseErrorCollection
Sourcepub fn fatal(error: FatalParseError) -> ParseErrorCollection
pub fn fatal(error: FatalParseError) -> ParseErrorCollection
Create a fatal error collection from a single fatal error
Sourcepub fn multiple(
errors: Vec<RecoverableParseError>,
source_code: Option<String>,
file_name: Option<String>,
) -> ParseErrorCollection
pub fn multiple( errors: Vec<RecoverableParseError>, source_code: Option<String>, file_name: Option<String>, ) -> ParseErrorCollection
Create a multiple error collection from recoverable errors This enriches all errors with file_name and source_code