macro_rules! field {
($node:ident, $name:expr) => { ... };
(recover, $ctx:expr, $node:expr, $name:expr) => { ... };
}Expand description
Get the named field of a node, or return a syntax error with a message if it doesn’t exist.
macro_rules! field {
($node:ident, $name:expr) => { ... };
(recover, $ctx:expr, $node:expr, $name:expr) => { ... };
}Get the named field of a node, or return a syntax error with a message if it doesn’t exist.