macro_rules! named_child {
($node:ident) => { ... };
($node:ident, $i:literal) => { ... };
($node:ident, $i:literal, $msg:expr) => { ... };
(recover, $ctx:expr, $node:expr) => { ... };
(recover, $ctx:expr, $node:expr, $i:literal) => { ... };
}Expand description
Get the i-th named child of a node, or return a syntax error with a message if it doesn’t exist.