get_documentation

Function get_documentation 

pub fn get_documentation(name: &str) -> Option<String>
Fetch Essence syntax documentation from Conjure’s docs/bits/ folder on GitHub.

name is the name of the documentation file (without .md suffix). If the file is not found or an error occurs, returns None.