pub struct ParseContext<'a> {
pub source_code: &'a str,
pub root: &'a Node<'a>,
pub symbols: Option<SymbolTablePtr>,
pub errors: &'a mut Vec<RecoverableParseError>,
pub source_map: &'a mut SourceMap,
pub decl_spans: &'a mut BTreeMap<Name, u32>,
pub typechecking_context: TypecheckingContext,
}Expand description
Context for parsing, containing shared state passed through parser functions.
Fields
source_code: &'a strroot: &'a Node<'a>symbols: Option<SymbolTablePtr>errors: &'a mut Vec<RecoverableParseError>source_map: &'a mut SourceMapdecl_spans: &'a mut BTreeMap<Name, u32>typechecking_context: TypecheckingContextImplementations
Sourceimpl<'a> ParseContext<'a>
impl<'a> ParseContext<'a>
pub fn new( source_code: &'a str, root: &'a Node<'a>, symbols: Option<SymbolTablePtr>, errors: &'a mut Vec<RecoverableParseError>, source_map: &'a mut SourceMap, decl_spans: &'a mut BTreeMap<Name, u32>, ) -> ParseContext<'a>
pub fn record_error(&mut self, error: RecoverableParseError)
Sourcepub fn with_new_symbols(
&mut self,
symbols: Option<SymbolTablePtr>,
) -> ParseContext<'_>
pub fn with_new_symbols( &mut self, symbols: Option<SymbolTablePtr>, ) -> ParseContext<'_>
Create a new ParseContext with different symbols but sharing source_code, root, errors, and source_map.
pub fn save_decl_span(&mut self, name: Name, span_id: u32)
pub fn lookup_decl_span(&self, name: &Name) -> Option<u32>
pub fn lookup_decl_line(&self, name: &Name) -> Option<u32>
Sourcepub fn add_span_and_doc_hover(
&mut self,
node: &Node<'_>,
doc_key: &str,
kind: SymbolKind,
ty: Option<String>,
decl_span: Option<u32>,
)
pub fn add_span_and_doc_hover( &mut self, node: &Node<'_>, doc_key: &str, kind: SymbolKind, ty: Option<String>, decl_span: Option<u32>, )
Helper to add to span and documentation hover info into the source map