pub enum ReprInstantiateError {
AlreadyExists(DeclarationPtr, &'static str),
ConflictingRepresentation {
declaration: DeclarationPtr,
existing: &'static str,
requested: &'static str,
},
NoDomain(DeclarationPtr),
BadKind(DeclarationPtr, String),
BadDomain(DeclarationPtr, Moo<Domain>),
Other(Error),
}Expand description
Errors that can be thrown by ReprDomainLevel::instantiate
Variants
AlreadyExists(DeclarationPtr, &'static str)
An instance of this representation already exists for this variable
ConflictingRepresentation
Channelling is disabled and another representation has already been selected.
NoDomain(DeclarationPtr)
The given variable had no domain
BadKind(DeclarationPtr, String)
The given variable was of an unsupported kind
BadDomain(DeclarationPtr, Moo<Domain>)
This variable’s domain is different from the one this domain-level representation is for
Other(Error)
Can’t instantiate representation for a different reason