get_applicable_repr_by_short_name

Function get_applicable_repr_by_short_name 

pub fn get_applicable_repr_by_short_name(
    decl: &DeclarationPtr,
    short_name: &str,
) -> Option<&'static dyn ReprRuleStored>
Look up a representation by short name that is applicable to decl.

Short names are not unique – nine representations are called packed – so a declaration is required to disambiguate, via ReprRuleStored::probe_for. There is deliberately no lookup by short name alone.