rewrite_model

Function rewrite_model 

pub fn rewrite_model<'a>(
    model: &Model,
    rule_sets: &Vec<&'a RuleSet<'a>>,
    config: RewriteConfig,
) -> Result<Model, RewriteError>
Rewrites a model by applying rules in priority order, trying enclosing expressions before their descendants at each priority.