pub enum Heuristic {
First,
Random,
Compact,
Interactive,
All,
}Expand description
Strategy used when a modelling decision has more than one applicable answer.
Variants
First
Random
Compact
Interactive
Prompt on stdin, or consume values from set_heuristic_responses.
All
Enumerate every applicable choice. This is supported by the integration model generator, but is not accepted by the command-line interface yet.