Model

Struct Model 

pub struct Model {
    pub search_order: Option<Vec<Name>>,
    pub dominance: Option<Expression>,
    pub context: Arc<RwLock<Context<'static>>>,
    /* private fields */
}
An Essence model.

Fields

search_order: Option<Vec<Name>>dominance: Option<Expression>context: Arc<RwLock<Context<'static>>>

Implementations

Source

impl Model

pub fn new(context: Arc<RwLock<Context<'static>>>) -> Model

Creates a new top-level model from the given context.

pub fn new_in_parent_scope(parent: SymbolTablePtr) -> Model

Creates a new model whose symbol table has parent as parent scope.

pub fn symbols_ptr_unchecked(&self) -> &SymbolTablePtr

The symbol table for this model as a pointer.

pub fn symbols_ptr_unchecked_mut(&mut self) -> &mut SymbolTablePtr

The symbol table for this model as a mutable pointer.

pub fn symbols(&self) -> RwLockReadGuard<'_, RawRwLock, SymbolTable>

The symbol table for this model as a reference.

pub fn symbols_mut(&mut self) -> RwLockWriteGuard<'_, RawRwLock, SymbolTable>

The symbol table for this model as a mutable reference.

pub fn root(&self) -> &Expression

The root node of this model.

pub fn root_mut_unchecked(&mut self) -> &mut Expression

The root node of this model, as a mutable reference.

The caller is responsible for ensuring that the root node remains an Expression::Root.

pub fn replace_root(&mut self, new_root: Expression) -> Expression

Replaces the root node with new_root, returning the old root node.

pub fn constraints(&self) -> &Vec<Expression>

The top-level constraints in this model.

pub fn clauses(&self) -> &Vec<CnfClause>

The cnf clauses in this model.

pub fn constraints_mut(&mut self) -> &mut Vec<Expression>

The top-level constraints in this model as a mutable vector.

pub fn clauses_mut(&mut self) -> &mut Vec<CnfClause>

The cnf clauses in this model as a mutable vector.

pub fn replace_constraints( &mut self, new_constraints: Vec<Expression>, ) -> Vec<Expression>

Replaces the top-level constraints with new_constraints, returning the old ones.

pub fn replace_clauses(&mut self, new_clauses: Vec<CnfClause>) -> Vec<CnfClause>

Replaces the cnf clauses with new_clauses, returning the old ones.

pub fn add_constraint(&mut self, constraint: Expression)

Adds a top-level constraint.

pub fn add_clause(&mut self, clause: CnfClause)

Adds a cnf clause.

pub fn add_constraints(&mut self, constraints: Vec<Expression>)

Adds top-level constraints.

pub fn add_clauses(&mut self, clauses: Vec<CnfClause>)

Adds cnf clauses.

pub fn add_symbol(&mut self, decl: DeclarationPtr) -> Option<()>

Adds a new symbol to the symbol table.

pub fn into_single_expression(self) -> Expression

Converts the constraints in this model to a single expression suitable for use inside another expression tree.

pub fn collect_stable_id_mapping(&self) -> HashMap<ObjId, ObjId>

Collects all ObjId values from the model using uniplate traversal.