pub enum AbstractLiteral<T>where
T: AbstractLiteralValue,{
Set(Vec<T>),
MSet(Vec<T>),
Matrix(Vec<T>, <T as AbstractLiteralValue>::Dom),
Tuple(Vec<T>),
Record(Vec<Field<T>>),
Sequence(Vec<T>),
Function(Vec<(T, T)>),
Variant(Moo<Field<T>>),
Partition(Vec<Vec<T>>),
Relation(Vec<Vec<T>>),
Permutation(Vec<Vec<T>>),
}Variants
Set(Vec<T>)
MSet(Vec<T>)
Matrix(Vec<T>, <T as AbstractLiteralValue>::Dom)
A 1 dimensional matrix slice with an index domain.
Tuple(Vec<T>)
Record(Vec<Field<T>>)
Sequence(Vec<T>)
Function(Vec<(T, T)>)
Variant(Moo<Field<T>>)
Partition(Vec<Vec<T>>)
Relation(Vec<Vec<T>>)
Permutation(Vec<Vec<T>>)
Cycle notation for a permutation: each inner vec is one cycle. Unlike Partition, this is
sparse – any element of the permutation’s domain not mentioned in any cycle is an
implicit fixed point (maps to itself), rather than every element needing to be covered.
Implementations
Sourceimpl<T> AbstractLiteral<T>where
T: AbstractLiteralValue,
impl<T> AbstractLiteral<T>where
T: AbstractLiteralValue,
Sourcepub fn matrix_implied_indices(elems: Vec<T>) -> AbstractLiteral<T>
pub fn matrix_implied_indices(elems: Vec<T>) -> AbstractLiteral<T>
Creates a matrix with elements elems, with domain int(1..).
This acts as a variable sized list.
Sourcepub fn unwrap_list(&self) -> Option<&Vec<T>>
pub fn unwrap_list(&self) -> Option<&Vec<T>>
If the AbstractLiteral is a list, returns its elements.
A list is any a matrix with the domain int(1..). This includes matrix literals without
any explicitly specified domain.
Sourceimpl AbstractLiteral<Expression>
impl AbstractLiteral<Expression>
Sourcepub fn into_literals(self) -> Option<AbstractLiteral<Literal>>
pub fn into_literals(self) -> Option<AbstractLiteral<Literal>>
If all the elements are literals, returns this as an AbstractLiteralNone.