pub struct Rule<'a> {
pub name: &'a str,
pub application: fn(&Expression, &SymbolTable) -> Result<RuleEffect, ApplicationError>,
pub rule_sets: &'a [(&'a str, u16)],
pub prefilters: Option<&'static [RulePrefilter]>,
pub failure_invalidation: RuleFailureInvalidation,
}Expand description
A rule with a name, application function, and rule sets.
Fields
nameThe name of the rule.applicationThe function to apply the rule.rule_setsA list of rule set names and priorities that this rule is a part of. This is used to populate rulesets at runtime.
Fields
name: &'a strapplication: fn(&Expression, &SymbolTable) -> Result<RuleEffect, ApplicationError>rule_sets: &'a [(&'a str, u16)]prefilters: Option<&'static [RulePrefilter]>Complete prefilter alternatives this rule applies to, or None for universal rules.
failure_invalidation: RuleFailureInvalidationWhich state changes can make a failed application become applicable.
Implementations
Sourceimpl<'a> Rule<'a>
impl<'a> Rule<'a>
pub const fn new( name: &'a str, application: fn(&Expression, &SymbolTable) -> Result<RuleEffect, ApplicationError>, rule_sets: &'a [(&'static str, u16)], ) -> Rule<'a>
pub fn apply( &self, expr: &Expression, symbols: &SymbolTable, ) -> Result<RuleEffect, ApplicationError>